Author: hrs
Date: Sun Jan 22 11:34:24 2012
New Revision: 230458
URL: http://svn.freebsd.org/changeset/base/230458

Log:
  - Replace "wtmp" with "utx.log" because last(1) no longer reads wtmp.
  - A real filename is now shown in an output report when "-f file" is 
specified.
  - Add Xr lastlogin into last(1) manual page.
  
  Reviewed by:  ed
  MFC after:    1 week

Modified:
  head/usr.bin/last/last.1
  head/usr.bin/last/last.c

Modified: head/usr.bin/last/last.1
==============================================================================
--- head/usr.bin/last/last.1    Sun Jan 22 11:20:42 2012        (r230457)
+++ head/usr.bin/last/last.1    Sun Jan 22 11:34:24 2012        (r230458)
@@ -198,6 +198,7 @@ login data base
 .El
 .Sh SEE ALSO
 .Xr lastcomm 1 ,
+.Xr lastlogin 8 ,
 .Xr getutxent 3 ,
 .Xr ac 8
 .Sh HISTORY

Modified: head/usr.bin/last/last.c
==============================================================================
--- head/usr.bin/last/last.c    Sun Jan 22 11:20:42 2012        (r230457)
+++ head/usr.bin/last/last.c    Sun Jan 22 11:34:24 2012        (r230458)
@@ -83,7 +83,7 @@ struct idtab {
 static const   char *crmsg;                    /* cause of last reboot */
 static time_t  currentout;                     /* current logout value */
 static long    maxrec;                         /* records to display */
-static const   char *file = NULL;              /* wtmp file */
+static const   char *file = NULL;              /* utx.log file */
 static int     sflag = 0;                      /* show delta in seconds */
 static int     width = 5;                      /* show seconds in delta */
 static int     yflag;                          /* show year */
@@ -194,7 +194,7 @@ main(int argc, char *argv[])
 
 /*
  * wtmp --
  *     read through the wtmp file
  */
 static void
 wtmp(void)
@@ -229,13 +229,13 @@ wtmp(void)
                doentry(&buf[--amount]);
 
        tm = localtime(&t);
-       (void) strftime(ct, sizeof(ct), "\nwtmp begins %+\n", tm);
-       printf("%s", ct);
+       (void) strftime(ct, sizeof(ct), "%+", tm);
+       printf("\n%s begins %s\n", ((file == NULL) ? "utx.log" : file), ct);
 }
 
 /*
  * doentry --
  *     process a single wtmp entry
  */
 static void
 doentry(struct utmpx *bp)
@@ -194,7 +194,7 @@ main(int argc, char *argv[])
 /*
  * wtmp --
- *     read through the wtmp file
+ *     read through the utx.log file
  */
 static void
@@ -229,13 +229,13 @@ wtmp(void)
 /*
  * doentry --
- *     process a single wtmp entry
+ *     process a single utx.log entry
  */
 static void
_______________________________________________
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"

Reply via email to